These docs have moved...
========================

.. meta::
   :http-equiv=refresh: 4;URL='http://django-calaccess.californiacivicdata.org/en/latest/calaccess/dbtables.html'


...to `django-calaccess.californiacivicdata.org/en/latest/calaccess/dbtables.html <http://django-calaccess.californiacivicdata.org/en/latest/calaccess/dbtables.html>`_. You will be re-directed in a few seconds.
